@@ -4,6 +4,7 @@ from sqlalchemy import String
 from sqlalchemy import ForeignKey
 from marshmallow import fields
 from marshmallow import Schema
+from marshmallow import pre_load
 
 from .base import Base
 
@@ -25,7 +26,13 @@ class AddressSchema(Schema):
 
     id = fields.Integer()
     user_id = fields.Integer(load_only=True)
-    zip_code = fields.String(data_key='zipCode')
+    zip_code = fields.String()
     city = fields.String()
     address = fields.String()
     description = fields.String(allow_none=True)
+
+    @pre_load
+    def fix_zip_code(self, data, **kwargs):
+        data['zip_code'] = data['zipCode']
+        del data['zipCode']
+        return data
